==> cdktf-provider-aws-10.0.5-sources.jar: com/hashicorp/cdktf/providers/aws/medialive_multiplex_program/MedialiveMultiplexProgramMultiplexProgramSettingsVideoSettings.java <==
package com.hashicorp.cdktf.providers.aws.medialive_multiplex_program;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-07T01:25:54.771Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.medialiveMultiplexProgram.MedialiveMultiplexProgramMultiplexProgramSettingsVideoSettings")
@software.amazon.jsii.Jsii.Proxy(MedialiveMultiplexProgramMultiplexProgramSettingsVideoSettings.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface MedialiveMultiplexProgramMultiplexProgramSettingsVideoSettings extends software.amazon.jsii.JsiiSerializable {

    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/medialive_multiplex_program#constant_bitrate MedialiveMultiplexProgram#constant_bitrate}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Number getConstantBitrate() {
        return null;
    }

    /**
     * statemux_settings block.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/medialive_multiplex_program#statemux_settings MedialiveMultiplexProgram#statemux_settings}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.medialive_multiplex_program.MedialiveMultiplexProgramMultiplexProgramSettingsVideoSettingsStatemuxSettings getStatemuxSettings() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link MedialiveMultiplexProgramMultiplexProgramSettingsVideoSettings}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link MedialiveMultiplexProgramMultiplexProgramSettingsVideoSettings}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<MedialiveMultiplexProgramMultiplexProgramSettingsVideoSettings> {
        java.lang.Number constantBitrate;
        com.hashicorp.cdktf.providers.aws.medialive_multiplex_program.MedialiveMultiplexProgramMultiplexProgramSettingsVideoSettingsStatemuxSettings statemuxSettings;

        /**
         * Sets the value of {@link MedialiveMultiplexProgramMultiplexProgramSettingsVideoSettings#getConstantBitrate}
         * @param constantBitrate Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/medialive_multiplex_program#constant_bitrate MedialiveMultiplexProgram#constant_bitrate}.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder constantBitrate(java.lang.Number constantBitrate) {
            this.constantBitrate = constantBitrate;
            return this;
        }

        /**
         * Sets the value of {@link MedialiveMultiplexProgramMultiplexProgramSettingsVideoSettings#getStatemuxSettings}
         * @param statemuxSettings statemux_settings block.
         *                         Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/medialive_multiplex_program#statemux_settings MedialiveMultiplexProgram#statemux_settings}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder statemuxSettings(com.hashicorp.cdktf.providers.aws.medialive_multiplex_program.MedialiveMultiplexProgramMultiplexProgramSettingsVideoSettingsStatemuxSettings statemuxSettings) {
            this.statemuxSettings = statemuxSettings;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link MedialiveMultiplexProgramMultiplexProgramSettingsVideoSettings}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public MedialiveMultiplexProgramMultiplexProgramSettingsVideoSettings build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link MedialiveMultiplexProgramMultiplexProgramSettingsVideoSettings}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements MedialiveMultiplexProgramMultiplexProgramSettingsVideoSettings {
        private final java.lang.Number constantBitrate;
        private final com.hashicorp.cdktf.providers.aws.medialive_multiplex_program.MedialiveMultiplexProgramMultiplexProgramSettingsVideoSettingsStatemuxSettings statemuxSettings;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.constantBitrate = software.amazon.jsii.Kernel.get(this, "constantBitrate", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.statemuxSettings = software.amazon.jsii.Kernel.get(this, "statemuxSettings", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.medialive_multiplex_program.MedialiveMultiplexProgramMultiplexProgramSettingsVideoSettingsStatemuxSettings.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.constantBitrate = builder.constantBitrate;
            this.statemuxSettings = builder.statemuxSettings;
        }

        @Override
        public final java.lang.Number getConstantBitrate() {
            return this.constantBitrate;
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.medialive_multiplex_program.MedialiveMultiplexProgramMultiplexProgramSettingsVideoSettingsStatemuxSettings getStatemuxSettings() {
            return this.statemuxSettings;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getConstantBitrate() != null) {
                data.set("constantBitrate", om.valueToTree(this.getConstantBitrate()));
            }
            if (this.getStatemuxSettings() != null) {
                data.set("statemuxSettings", om.valueToTree(this.getStatemuxSettings()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.medialiveMultiplexProgram.MedialiveMultiplexProgramMultiplexProgramSettingsVideoSettings"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            MedialiveMultiplexProgramMultiplexProgramSettingsVideoSettings.Jsii$Proxy that = (MedialiveMultiplexProgramMultiplexProgramSettingsVideoSettings.Jsii$Proxy) o;

            if (this.constantBitrate != null ? !this.constantBitrate.equals(that.constantBitrate) : that.constantBitrate != null) return false;
            return this.statemuxSettings != null ? this.statemuxSettings.equals(that.statemuxSettings) : that.statemuxSettings == null;
        }

        @Override
        public final int hashCode() {
            int result = this.constantBitrate != null ? this.constantBitrate.hashCode() : 0;
            result = 31 * result + (this.statemuxSettings != null ? this.statemuxSettings.hashCode() : 0);
            return result;
        }
    }
}

==> cdktf-provider-aws-16.0.4-sources.jar: com/hashicorp/cdktf/providers/aws/medialive_multiplex_program/MedialiveMultiplexProgramMultiplexProgramSettingsVideoSettings.java <==
package com.hashicorp.cdktf.providers.aws.medialive_multiplex_program;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.85.0 (build 08ee592)", date = "2023-07-21T05:23:10.776Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.medialiveMultiplexProgram.MedialiveMultiplexProgramMultiplexProgramSettingsVideoSettings")
@software.amazon.jsii.Jsii.Proxy(MedialiveMultiplexProgramMultiplexProgramSettingsVideoSettings.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface MedialiveMultiplexProgramMultiplexProgramSettingsVideoSettings extends software.amazon.jsii.JsiiSerializable {

    /**
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/medialive_multiplex_program#constant_bitrate MedialiveMultiplexProgram#constant_bitrate}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Number getConstantBitrate() {
        return null;
    }

    /**
     * statmux_settings block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/medialive_multiplex_program#statmux_settings MedialiveMultiplexProgram#statmux_settings}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getStatmuxSettings() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link MedialiveMultiplexProgramMultiplexProgramSettingsVideoSettings}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link MedialiveMultiplexProgramMultiplexProgramSettingsVideoSettings}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<MedialiveMultiplexProgramMultiplexProgramSettingsVideoSettings> {
        java.lang.Number constantBitrate;
        java.lang.Object statmuxSettings;

        /**
         * Sets the value of {@link MedialiveMultiplexProgramMultiplexProgramSettingsVideoSettings#getConstantBitrate}
         * @param constantBitrate Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/medialive_multiplex_program#constant_bitrate MedialiveMultiplexProgram#constant_bitrate}.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder constantBitrate(java.lang.Number constantBitrate) {
            this.constantBitrate = constantBitrate;
            return this;
        }

        /**
         * Sets the value of {@link MedialiveMultiplexProgramMultiplexProgramSettingsVideoSettings#getStatmuxSettings}
         * @param statmuxSettings statmux_settings block.
         *                        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/medialive_multiplex_program#statmux_settings MedialiveMultiplexProgram#statmux_settings}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder statmuxSettings(com.hashicorp.cdktf.IResolvable statmuxSettings) {
            this.statmuxSettings = statmuxSettings;
            return this;
        }

        /**
         * Sets the value of {@link MedialiveMultiplexProgramMultiplexProgramSettingsVideoSettings#getStatmuxSettings}
         * @param statmuxSettings statmux_settings block.
         *                        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/medialive_multiplex_program#statmux_settings MedialiveMultiplexProgram#statmux_settings}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder statmuxSettings(java.util.List<? extends com.hashicorp.cdktf.providers.aws.medialive_multiplex_program.MedialiveMultiplexProgramMultiplexProgramSettingsVideoSettingsStatmuxSettings> statmuxSettings) {
            this.statmuxSettings = statmuxSettings;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link MedialiveMultiplexProgramMultiplexProgramSettingsVideoSettings}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public MedialiveMultiplexProgramMultiplexProgramSettingsVideoSettings build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link MedialiveMultiplexProgramMultiplexProgramSettingsVideoSettings}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements MedialiveMultiplexProgramMultiplexProgramSettingsVideoSettings {
        private final java.lang.Number constantBitrate;
        private final java.lang.Object statmuxSettings;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.constantBitrate = software.amazon.jsii.Kernel.get(this, "constantBitrate", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.statmuxSettings = software.amazon.jsii.Kernel.get(this, "statmuxSettings", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.constantBitrate = builder.constantBitrate;
            this.statmuxSettings = builder.statmuxSettings;
        }

        @Override
        public final java.lang.Number getConstantBitrate() {
            return this.constantBitrate;
        }

        @Override
        public final java.lang.Object getStatmuxSettings() {
            return this.statmuxSettings;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getConstantBitrate() != null) {
                data.set("constantBitrate", om.valueToTree(this.getConstantBitrate()));
            }
            if (this.getStatmuxSettings() != null) {
                data.set("statmuxSettings", om.valueToTree(this.getStatmuxSettings()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.medialiveMultiplexProgram.MedialiveMultiplexProgramMultiplexProgramSettingsVideoSettings"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            MedialiveMultiplexProgramMultiplexProgramSettingsVideoSettings.Jsii$Proxy that = (MedialiveMultiplexProgramMultiplexProgramSettingsVideoSettings.Jsii$Proxy) o;

            if (this.constantBitrate != null ? !this.constantBitrate.equals(that.constantBitrate) : that.constantBitrate != null) return false;
            return this.statmuxSettings != null ? this.statmuxSettings.equals(that.statmuxSettings) : that.statmuxSettings == null;
        }

        @Override
        public final int hashCode() {
            int result = this.constantBitrate != null ? this.constantBitrate.hashCode() : 0;
            result = 31 * result + (this.statmuxSettings != null ? this.statmuxSettings.hashCode() : 0);
            return result;
        }
    }
}
